@@ -669,7 +669,7 @@ class Node(metaclass=NodeMeta):
         cmdargs = self.config.get_cmdline_args()
 
         # Module-specific args..
-        supported_extra_args = self.supported_extra_args
+        supported_extra_args = self.get_supported_extra_args()
 
         # Insert the global args if not already present. Module
         # specific value overrides the global values
@@ -825,7 +825,6 @@ class Node(metaclass=NodeMeta):
         conf - Module configuration specified in config
 
         """
-
         readonly = self.config.readonly
 
         # => Check whether internal configuration is valid
@@ -1065,6 +1064,9 @@ class Node(metaclass=NodeMeta):
         ----------
         None
 
+        .. deprecated:: 
+           Use configure/other functions to complete the initialization..
+
         """
         pass
 
