@@ -210,11 +210,18 @@ class Dataset(DataSource):
         # Read the file
         if filename.lower().endswith('.csv'):
             df = pd.read_csv(fd, nrows=10)
+        elif filename.lower().endswith('.csv.gz'):
+            df = pd.read_csv(fd, nrows=10, compression='gzip', error_bad_lines=False)
+        elif filename.lower().endswith('.tsv.gz'):
+            df = pd.read_csv(fd, nrows=10, sep='\t', compression='gzip',
+                             error_bad_lines=False)
         elif filename.lower().endswith('.tsv'):
             df = pd.read_csv(fd, nrows=10, sep='\t')
-        else:
+        elif filename.lower().endswith('.pq') or filename.lower().endswith(".pq.sample"):
             df = pd.read_parquet(fd)
             df = df.head(10)
+        else:
+            raise Exception(f"Unknown file format: {filename}")
 
         return df
 
