@@ -6,6 +6,7 @@ import logging
 import traceback
 import importlib
 import subprocess
+import base64
 from datetime import datetime
 from dateutil import parser as dateparser
 from dateutil.tz import tzlocal
@@ -75,11 +76,22 @@ def read_siteconf_json(filename, app={}, context={}):
 
 def read_siteconf(filename=None, app={}, context={}):
 
-
     # If context not available, then generate it.
     if len(context) == 0:
         context = Context().asdict()
 
+    # This overrides everything else...
+    if 'ENRICH_SITECONF' in os.environ:
+        try:
+            import sitelib
+            encoded = os.environ['ENRICH_SITECONF']
+            confbytes = base64.b64decode(encoded)
+            siteconf  = sitelib.decode_bytes(confbytes)
+            siteconf = json.loads(siteconf)
+            return siteconf
+        except:
+            pass
+
     if filename is not None:
         return read_siteconf_json(filename, app)
 
