@@ -401,6 +401,51 @@ def prepare_setup(component, target):
     print(greenbg("Created a package in {}".format(target)))
     print(redbg("Note: Please look at fixtures in tests/fixtures and update the paths for data_root and statedir"))
 
+def prepare_dashboard(target, templatepath):
+    """
+    Bootstrap a dashboard
+    """
+    appname = prompt('appname>')
+
+    templatedir = os.path.join(target, "templates", appname)
+    try:
+        os.makedirs(target)
+        os.makedirs(templatedir)
+    except:
+        pass
+
+    dashboard_root = get_template_path('dashboard')
+
+    # First copy the py files
+    files = glob2.glob(dashboard_root + "/*py")
+    for f in files:
+        content = open(f).read()
+        content = content.replace("APPNAME", appname)
+        basename = os.path.basename(f)
+        targetfile = os.path.join(target, basename)
+        with open(targetfile, 'w') as fd:
+            fd.write(content)
+        print(basename, "=>", targetfile)
+
+    # Now copy the html files...
+    files = glob2.glob(os.path.join(dashboard_root,'templates',"*html"))
+    print(files)
+    for f in files:
+        content = open(f).read()
+        content = content.replace("APPNAME", appname)
+        basename = os.path.basename(f)
+        targetfile = os.path.join(templatedir, basename)
+        with open(targetfile, 'w') as fd:
+            fd.write(content)
+        print(basename, "=>", targetfile)
+
+    print("Add the following to the enrich.json applications")
+    print(json.dumps({
+        'url': f'{appname}:index',
+        'description': 'Update me',
+        'name': f'{appname.title()}'
+    },indent=4))
+
 
 def prepare_asset(what, target, templatepath):
 
@@ -742,6 +787,11 @@ def prepare_script_minimal(path, templatepath):
     if os.path.exists(path):
         raise Exception("Output path already exists. Please remove it")
 
+    try:
+        conf = read_conf()
+    except:
+        conf = {}
+
     validators = {
         'confname': NameValidator(),
         'runname': NameValidator(),
@@ -752,6 +802,12 @@ def prepare_script_minimal(path, templatepath):
 
     context = {
         'today': date.today().isoformat(),
+        "author_name": conf.get('repository',{}).get('author','John Smith'),
+        "author_email": conf.get('repository',{}).get('email','john.smith@alphainc.com'),
+        "repo_giturl": conf.get('repository',{}).get('giturl','git@github.com:alpha/enrich-alpha.git'),
+        "org_logourl": conf.get('org',{}).get('logo',"https://alphainc.com/logo/small.png"),
+        "org_name": conf.get('org',{}).get('name',"Alpha Inc"),
+        "org_description": conf.get('description',{}).get('name',"Alpha retail"),
     }
 
     variables = get_variables(templatepath)
@@ -824,7 +880,6 @@ def prepare_transform_script(path, templatepath,what='simpletransform'):
 
     prepare_script_minimal(path, lib_template)
 
-
 def prepare_sparkjob(path, templatepath):
     """
     Bootstrap a new sparkjob
@@ -946,6 +1001,8 @@ def bootstrap(component, path, templatepath):
         prepare_transform_script(path, templatepath,what='simpletransform')
     elif component in ['transform-helloworld']:
         prepare_transform_script(path, templatepath, what='helloworld')
+    elif component in ['transform-query']:
+        prepare_transform_script(path, templatepath, what='query')
     #elif component == 'model':
     #    prepare_component('model', path, templatepath)
     #elif component == 'skin':
@@ -956,6 +1013,8 @@ def bootstrap(component, path, templatepath):
         prepare_repo(path)
     elif component == 'asset':
         prepare_asset('asset', path, templatepath)
+    elif component == 'dashboard':
+        prepare_dashboard(path, templatepath)
     elif component in ['tasklib', 'task-lib']:
         prepare_tasklib(path, templatepath)
     elif component in ['taskconf', 'task-conf']:
@@ -2720,4 +2779,3 @@ def test_task(taskdir, capture=False, context=None):
             if i < len(tests) - 1:
                 print("Skipping the rest of the testing")
                 break
-
